--[[ 
Let's Ride 7.2.0.11

LetsRide.lua is simple World of Warcraft Addon that randomly
generates a mount from the list of mounts possessed by the character.

LetsRide.lua has a built in check to pick an appropriate mount or the
user can force a "special" mount or a "favorite" mount.

By default LetsRide.lua will summon a flyable mount where flying is
allowed. When flying is NOT allowed, LetsRide.lua will summon either a
ground mount or, if swimming, a water walking mount (mount must be usable by character).

Special mounts are arrays of mounts divided into mounts that have vendors, can
carry passengers (divided into flying and ground subcategories), can
walk on water, increase swim speed, and the special AQ40 only mounts.
Special mounts can be assigned specific key assignments from the
user interface menu <NOT YET IMPLIMENTED>.


To do list:
40. User Interface
	a. create a button
	b. create menu interface
	c. User Input
		1) allow users to "key bind" special mount arrays
		2) allow users to define mount priorities
50. Add druid travel form handling
	a. allow user to "key bind" travel form
	b. allow user to determine priority over mounts
		
*The Anglers Fishing Raft (item:85500, spell:124036) is not a mount. No
decision has been made to include / exclude the raft.
--]]

local addonName, addonTable = ...

--[[
local LRFrame = CreateFrame("FRAME")
--  LRFrame:RegisterEvent("PLAYER_LOGOUT");
  LRFrame:RegisterEvent("ADDON_LOADED");

function LRFrame:OnEvent(event, arg)
	if event == "ADDON_LOADED" and arg == "LetsRide" then
		print("Let's Ride v7.2.0.10 Loaded")
		if EFFirstRun == nil then
			EFFirstRun = true;
		end
		if EForagerDreanorNotice == nil then
			EForagerDreanorNotice = 1
		end			
	elseif event == "PLAYER_LOGOUT" then
		EFFirstRun = false;
		
		
	end
	
end
--]]

-- Simple slash command to mount
SLASH_LETSRIDE1, SLASH_LETSRIDE2 = '/lr', '/letsride';

-- MountUp determines which mount should be called
-- If appropriate, will use random to decide on the mount
local function MountUp(btn, myMounts)
  -- Currently ALT, Shift and right-click are hard coded. Need to write code
  -- that allows the user to determine keys for special cases
  local grnd, gPax, fly, fPax, vendor = myMounts[1], myMounts[2], myMounts[3], myMounts[4], myMounts[5]
  local swim, qiraji, seahorse, strider, chauffeur = myMounts[6], myMounts[7], myMounts[8], myMounts[9], myMounts[10]
  local zone = "blank"
	if (GetMapInfo() ~= nil) then
	  zone = GetMapInfo();
	end
	
	-- User overrides
	if (IsAltKeyDown() and btn == "RightButton" and swim) then	--Force swimming mounts
	  C_MountJournal.SummonByID( swim[random(#swim)]);
	elseif (IsAltKeyDown() and btn == "LeftButton" and strider) then
	  C_MountJournal.SummonByID( strider[random(#strider)]);        -- Force Water Strider
	elseif (IsShiftKeyDown() and btn == "LeftButton" and IsFlyableArea() and fPax) then 
	  C_MountJournal.SummonByID( fPax[random(#fPax)]);				-- Force passenger mounts
	elseif (IsShiftKeyDown() and btn == "LeftButton" and gPax) then
	  C_MountJournal.SummonByID( gPax[random(#gPax)]);
	elseif (IsShiftKeyDown() and btn == "RightButton" and gPax) then
	  C_MountJournal.SummonByID( gPax[random(#gPax)]);
	elseif (btn == "RightButton" and vendor) then				--Force vendors
	  C_MountJournal.SummonByID( vendor[random(#vendor)]);
	  
	-- Special Zones
	-- The Battle Tanks can only be summoned in Temple of Ahn'Qiraj (AQ40) so the zone
	-- must match exactly
	-- The Vashj'ir seahorse can be mounted in any of the Vashj'ir zones so the string.match
	-- function is called
	elseif (zone == "AhnQiraj" and qiraji) then					-- If in AQ40
	  C_MountJournal.SummonByID( qiraji[random(#qiraji)]);			-- Attempt to mount the battle tanks
	elseif (zone:match("Vashjir") and IsSwimming() and seahorse) then
	  C_MountJournal.SummonByID( seahorse);							-- Attempt to mount the Vashj'ir seahorse
	
	-- Best choice algorith picks a random mount from the appropriate category 
	elseif (IsFlyableArea() and fly) then				-- If flying is allowed
	  C_MountJournal.SummonByID( fly[random(#fly)]);		-- Call random flying mount
	elseif (IsSwimming() and strider) then				-- If cannot fly while swimming
	  C_MountJournal.SummonByID( strider[random(#strider)]);	-- Attempt to call the Strider
	elseif (IsSwimming() and swim) then					-- If no Strider while swimming
	  C_MountJournal.SummonByID( swim[random(#swim)]);		-- Attempt to call a swimming mount
	elseif grnd then
	  C_MountJournal.SummonByID( grnd[random(#grnd)]);
	elseif chauffeur then
	  C_MountJournal.SummonByID( chauffeur);
	else print("Well, you broke it. Contact Ridez administrator for tech support.")
	end
end

function SlashCmdList.LETSRIDE(msg, editbox)
--[[  local button = CreateFrame("Button", nil, mainframe)
	button:SetPoint("CENTER", mainframe, "CENTER", 0, 0)
	button:SetWidth(200)
	button:SetHeight(50)
	
	button:SetText("test")
	button:SetNormalFontObject("GameFontNormal")
	
  local ntex = button:CreateTexture()
	ntex:SetTexture("Interface/Buttons/UI-Panel-Button-Up")
	ntex:SetTexCoord(0, 0.625, 0, 0.6875)
	ntex:SetAllPoints()	
	button:SetNormalTexture(ntex)
	
  local htex = button:CreateTexture()
	htex:SetTexture("Interface/Buttons/UI-Panel-Button-Highlight")
	htex:SetTexCoord(0, 0.625, 0, 0.6875)
	htex:SetAllPoints()
	button:SetHighlightTexture(htex)
	
  local ptex = button:CreateTexture()
	ptex:SetTexture("Interface/Buttons/UI-Panel-Button-Down")
	ptex:SetTexCoord(0, 0.625, 0, 0.6875)
	ptex:SetAllPoints()
	button:SetPushedTexture(ptex)
--]]  
  local btn = GetMouseButtonClicked();
  local favPriority = 10									-- temp value, will eventually be replaced by user input (1-11)
	
	if IsMounted() then 									--If you are mounted
		if (btn=="LeftButton" or btn=="RightButton") then		-- Check if mouse button 1 or 2 was pressed
		  EjectPassengerFromSeat(btn=="LeftButton" and 1 or 2);		-- Eject respective passenger
		elseif (btn=="MiddleButton") then						-- Else if middle mouse button was pressed
		  C_MountJournal.Dismiss();									-- Dismount (dismiss Active mount)
		end
	
	elseif InCombatLockdown() then					 			-- If not permitted to mount
	  print("Can't mount while in combat")							-- Warn the user
	
	elseif (not IsMounted()) then								-- If not mounted
		if (btn=="MiddleButton") then								-- If using the raft
		  print("Not yet implemented")									-- Currently do nothing
		  -- C_ToyBox.GetToyInfo(85500)									-- 85500 is the Anglers Raft
		else
		  local sortedMounts, favoriteMounts = addonTable.SortMounts();		-- Sort mounts into appropriate arrays
			if sortedMounts == nil then									-- If you have no mounts that you can ride
			  print("You have no mounts you can use in this area");			-- Warn the user
			else
				local favor = random(10)
				if favor < favPriority then
				  MountUp(btn, favoriteMounts);								-- "It means, 'Get on your horses.'"
				else
				  MountUp(btn, sortedMounts);
				end
			end		
		end
	end
	
end