--[[ SortMounts is a sorting algorith for Lets Ride!
--]]

local addonName, addonTable = ...

-- IHaveMounts returns an array of "mount info" arrays for each 
-- mount the character can use.
local function IHaveMounts()
  local myMounts, m = {}, 1 									-- An array of the mounts this character owns (can use)
--  test counters for mountTypeID
--  local totalMounts, n230, n231, n232, n241, n242, n247, n248, n254, n269, n284 = 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
--  End counters
	for i,v in ipairs(C_MountJournal.GetMountIDs()) do
	  local _, _, _, _, iIsUsable, _, _, _, _, _, iIsCollected = C_MountJournal.GetMountInfoByID(v);	
		if (iIsCollected and iIsUsable) then						-- If this mount is collected and usable
		  myMounts[m] = {C_MountJournal.GetMountInfoByID(v)};			-- Add the mount information to myMounts
		  m = m+1;														-- Increment myMount
		end	
	end
  return myMounts;
 
end

-- Sort mounts into arrays of favorites and non-favorites
-- Also checks for unique mount properties like the Abyssal Seahorse or the Sandstone Drake
-- Returns sorted mount arrays
function addonTable.SortMounts()
  local grnd, g, fly, f, swim, s = {}, 1, {}, 1, {}, 1		-- Create ground and flying arrays
  local fGrnd, fg, fFly, ff, fSwim, fs = {}, 1, {}, 1, {}, 1
  local gPax, gp, fPax, fp = {}, 1, {}, 1					-- Create arrays for passenger mounts
  local fGPax, fgp, fFPax, ffp = {}, 1 , {}, 1
  local vendor, ve, strider, st, qiraji, q = {}, 1, {}, 1, {}, 1	-- Create arrays for special cases
  local fVendor, fve, fStrider, fst, fQiraji, fq = {}, 1, {}, 1, {}, 1
  local seahorse, chauffeur										-- Create variable for Vashj'ir Seahorse and Heirloom Chauffeur
  local myMounts = IHaveMounts()
	
	if (myMounts[1] == nil) then return						-- If there are no usable mounts, return nil
	else
		for i,v in ipairs(myMounts) do
		  local iCreatureName, iSpellID, iIsFavorite, iMountID = v[1], v[2], v[7], v[12];
		  local _, _, _, _, iMountTypeID = C_MountJournal.GetMountInfoExtraByID(iMountID);
			if iMountTypeID == 232 then							-- If Abyssal Seahorse
			  seahorse = iMountID;									-- Save seahorse
			elseif iMountTypeID == 284 then						-- Else if Heirloom Chauffeur
			  chauffeur = iMountID;									-- Save chauffeur
						  
			elseif iIsFavorite then
				if iMountTypeID == 231 or iMountTypeID == 254 then		-- Else if a swimming mount
				  fSwim[fs] = iMountID;										-- Save swim mount
				  fs = fs+1;												-- Increment swim array index					
				
				elseif iMountTypeID == 241 then						-- Else if Quraji
				  fQiraji[fq] = iMountID;									-- Save Qaraji
				  fq = fq+1;												-- Increment Qaraji array index				
				elseif iMountTypeID == 230 or iMountTypeID == 269 then 			-- Else if ground mount
				  fGrnd[fg] = iMountID;									-- Add to ground array
				  fg = fg+1;												-- Increment ground array index
				
					if iMountTypeID == 269 then							-- If Strider
					  fStrider[fst] = iMountID;								-- Save Strider
					  fst = fst+1;											-- Increment Strider array index
					
					elseif addonTable.IsSpecialMount("gPax", iSpellID) then		-- Else if ground passenger mount
					  fGPax[fgp] = iMountID;									-- Save g-passenger
					  fgp = fgp+1;											-- Increment g-passenger array index
						if addonTable.IsSpecialMount("vendor", iSpellID) then			-- If vendor
						  fVendor[fve] = iMountID;								-- Save vendor
						  fve = fve+1;											-- Increment vendor array index	
						end
					end
				elseif iMountTypeID == 248 or iMountTypeID == 247 then			-- Else if is flying mount
				  fFly[ff] = iMountID;									-- Add to flying array
				  ff = ff+1;												-- Increment flying array index
					if addonTable.IsSpecialMount("fPax", iSpellID) then			-- If flying passenger mount
					  fFPax[ffp] = iMountID;									-- Save f-passenger
					  ffp = ffp+1;											-- Increment f-passenger array index
					end
				else												-- Else we didn't identify the mount
				  print("Error, mountTypeID undefined!")				-- Report finding
				  print("Mount name = " .. iCreatureName .. ", mountID=" .. iMountID .. ", mountTypeID=" .. iMountTypeID);
				end	
						
			elseif not iIsFavorite then
				if iMountTypeID == 231 or iMountTypeID == 254 then		-- Else if a swimming mount
				  swim[s] = iMountID;										-- Save swim mount
				  s = s+1;													-- Increment swim array index					
				
				elseif iMountTypeID == 241 then						-- Else if Quraji
				  qiraji[q] = iMountID;									-- Save Qaraji
				  q = q+1;												-- Increment Qaraji array index				
				elseif iMountTypeID == 230 or iMountTypeID == 269 then 			-- Else if ground mount
				  grnd[g] = iMountID;									-- Add to ground array
				  g = g+1;												-- Increment ground array index
				
					if iMountTypeID == 269 then							-- If Strider
					  strider[st] = iMountID;								-- Save Strider
					  st = st+1;											-- Increment Strider array index
					
					elseif addonTable.IsSpecialMount("gPax", iSpellID) then		-- Else if ground passenger mount
					  gPax[gp] = iMountID;									-- Save g-passenger
					  gp = gp+1;											-- Increment g-passenger array index
						if addonTable.IsSpecialMount("vendor", iSpellID) then			-- If vendor
						  vendor[ve] = iMountID;								-- Save vendor
						  ve = ve+1;											-- Increment vendor array index
						end
					end
				elseif iMountTypeID == 248 or iMountTypeID == 247 then			-- Else if is flying mount
				  fly[f] = iMountID;									-- Add to flying array
				  f = f+1;												-- Increment flying array index
					if addonTable.IsSpecialMount("fPax", iSpellID) then			-- If flying passenger mount
					  fPax[fp] = iMountID;									-- Save f-passenger
					  fp = fp+1;											-- Increment f-passenger array index
					end
				else												-- Else we didn't identify the mount
				  print("Error, mountTypeID undefined!")				-- Report finding
				  print("Mount name = " .. iCreatureName .. ", mountID=" .. iMountID .. ", mountTypeID=" .. iMountTypeID);
				end
			else												-- Else somehow is not and is not-not a favorite...
			  print("Eureka! Now entering quantim mounting!")		-- Report finding!
			end
		end
	end
	
	if fg == 1 then fGrnd = grnd; print("You had no favorite ground mounts")
	elseif g == 1 then grnd = fGrnd; print("You had no non-favorite ground mounts")
	end
	
	if fgp == 1 then fGPax = gPax;
	elseif gp == 1 then gPax = fGPax;
	end
	
	if ff == 1 then fFly = fly; print("You had no favorite flying mounts")
	elseif f == 1 then fly = fFly; print("You had no non-favorite ground mounts")
	end
	
	if ffp == 1 then fFPax = fPax;
	elseif fp == 1 then fPax = fFPax;
	end
	
	if fve == 1 then fVendor = vendor;
	elseif ve == 1 then vendor = fVendor;
	end
	
	if fs == 1 then fSwim = swim;
	elseif s == 1 then swim = fSwim;
	end
	
	if fq == 1 then fQiraji = qiraji;
	elseif q == 1 then qiraji = fQiraji;
	end
	
	if fst == 1 then fStrider = strider;
	elseif st == 1 then strider = fStrider;
	end
	
  local sortedMounts = {grnd, gPax, fly, fPax, vendor, swim, qiraji, seahorse, strider, chauffeur}
  local favoriteMounts = {fGrnd, fGPax, fFly, fFPax, fVendor, fSwim, fQiraji, seahorse, fStrider, chauffeur}
  return sortedMounts, favoriteMounts

end
